
clear all

global folder "C:\Users\Nico Voigtlnder\Dropbox\EMP\AER Submission\AER Final Package"
cd "$folder"

use EMP_Dataset_County_Level.dta


quietly{
tab region, gen(d_region)

gen pastoral_1290 = (100-percarable1290)/100
gen pastoral_1836=(percgrass1836+perccommon1836)/100
gen pastoral_1836_proxy = (100-percarable1836)/100
gen dmv = dmvsper100kacres/100
gen lndaysgrass = ln(daysgrass)

gen ln_popdensity = ln(poppermilesq1290)

gen SM_avg_Kussmaul= (SM_Kussmaul_1561_1640+SM_Kussmaul_1561_1640+SM_Kussmaul_1741_1820)/3

gen drop_taxpayers77_81 = (taxpayers1377-taxpayers1381)/ taxpayers1377
}
	
	
///////////////////// Tables for the Paper ////////////////

*Table 3:
	reg drop_taxpayers77_81 pastoral_1290, r
	reg drop_taxpayers77_81 pastoral_1290 ln_popdensity, r
	reg drop_taxpayers77_81 pastoral_1290 ln_popdensity d_region*, r
	ivreg2 drop_taxpayers77_81 (pastoral_1290=lndaysgrass), r 

	
///////////////////// Figures for the Paper ////////////////	
	
************* Figure 6: Partial Scatterplot *************	
reg drop_taxpayers77_81 pastoral_1290 ln_popdensity,r
predict y_hat
gen partial_y6a = drop_taxpayers77_81 - (y_hat-1.066633*pastoral_1290)
drop y_hat 

twoway (lfitci partial_y6a pastoral_1290, clcolor(black) fcolor(gray)) (scatter partial_y6a pastoral_1290, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)) ///
, xtitle(Share of Pastoral Land in 1290) ytitle(, size(medium)) ytitle(Drop in Poll Tax Payers 1377-81 (residual)) xtitle(, size(medium))  scheme(s1color) legend(off)
	
	
///////////////////// Tables for Online Appendix ////////////////
	
*Table B.4:
	reg pastoral_1290 lndaysgrass, r
	reg pastoral_1290 lndaysgrass feasibility_general,r
	reg pastoral_1836 lndaysgrass, r
	reg pastoral_1836 lndaysgrass feasibility_general,r	
	
*Table B.5, column 1 (the big IV Table): 
	ivreg2 drop_taxpayers77_81 (pastoral_1290=lndaysgrass feasibility_general), r 
	
	
/////////////////// Graphs for Online Appendix //////////////

*Figure B.4, left panel
twoway (scatteri 0.2 0.2 0.8 0.8, recast(line) lcolor(dknavy) lpattern(dash)) (lfit pastoral_1836_proxy pastoral_1836, lcolor(blue)) ///
(scatter pastoral_1836_proxy pastoral_1836, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)), ytitle(1 - Share of Arable Land in 1836) ///
 ytitle(, size(medium)) xtitle(Share of Pastoral Land in 1836) xtitle(, size(medium)) xscale(range(0.2 0.8)) yscale(range(0.2 0.8)) xlabel(0.2(0.1)0.8) ylabel(0.2(0.1)0.8) ///
 scheme(s1color) legend(off)

*Figure B.4, right panel
twoway (lfitci pastoral_1836 pastoral_1290, clcolor(black) fcolor(gray)) (scatter pastoral_1836 pastoral_1290, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)), ///
ytitle(Share of Pastoral Land in 1836) ytitle(, size(medium)) xtitle(Pastoral1290 = 1 - Share of Arable Land in 1290) xtitle(, size(medium)) scheme(s1color) legend(off)

**Figure B.5: Regions with more grass and commons have more livestock (i.e., land is not just fallow)
twoway (lfitci livestockunits pastoral_1836, clcolor(black) fcolor(gray)) (scatter livestockunits pastoral_1836, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)), ///
ytitle(Livestock units per 100 acres in 1867) ytitle(, size(medium)) xtitle(Share of Pastoral Land in 1836) xtitle(, size(medium)) scheme(s1color) legend(off)

*Figure B.7, left panel
twoway (lfitci pastoral_1290 lndaysgrass, clcolor(black) fcolor(gray)) (scatter pastoral_1290 lndaysgrass, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)) ///
, xtitle(ln(Days during which grass grows)) ytitle(, size(medium)) ytitle(Share of Pastoral Land in 1290) xtitle(, size(medium))  scheme(s1color) legend(off)
	
************* *Figure B.7, right panel: Partial Scatterplot for daysgrass *************	
reg pastoral_1290 lndaysgrass feasibility_general,r
predict y_hat
gen partial_y2 = lndaysgrass - (y_hat-.5452565*pastoral_1290)
drop y_hat 

twoway (lfitci partial_y2 lndaysgrass, clcolor(black) fcolor(gray)) (scatter partial_y2 lndaysgrass, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)) ///
, xtitle(ln(Days during which grass grows)) ytitle(, size(medium)) ytitle(Share of Pastoral Land in 1290 (residual)) xtitle(, size(medium))  scheme(s1color) legend(off)
		

*Figure B.13: Fraction of parishes classified as "Spring Marriage" by Kussmaul in 1561-1820 and percentage of pastoral agriculture 
twoway (lfitci SM_avg_Kussmaul pastoral_1290, clcolor(black) fcolor(gray)) (scatter SM_avg_Kussmaul pastoral_1290, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)) ///
, xtitle(Share of Pastoral Land in 1290) ytitle(, size(medium)) ytitle(Prevalence of Pastoral (Spring) Marriage) xtitle(, size(medium))  scheme(s1color) legend(off)

	
	
	
	
	
	
	
	
	
	
	
	
	
