clear all

global folder "C:\Users\Nico Voigtlnder\Dropbox\EMP\AER Submission\AER Final Package"
cd "$folder"

use EMP_Dataset_Parish_Panel.dta

quietly{
*DUMMIES
tab period, gen(d_period)
tab parish, gen(d_parish)
tab region, gen(d_region)

bysort county: egen SM_Kussmaul_county_avg = mean(SM_Kussmaul_county) if period==1625 | period==1675 | period==1775 

gen ln_age_mar = ln(fmage)
gen lndaysgrass = ln(daysgrass_county)
gen pastoral_1290 = (100-percarable1290)/100
gen pastoral_1836=(percgrass1836+perccommon1836)/100
gen dmv = dmvsper100kacres/100
}

///////////////////// Tables for the Paper ////////////////

*Table 4: Pastoral Production and Age at First Marriage
	*Col 1-3: Sample 1600-1837
	reg fmage pastoral_1290 dmv d_period1-d_period4, cl(county) 
	reg fmage pastoral_1290 dmv d_period1-d_period4 d_region*, cl(county)	
	ivreg2 fmage (pastoral_1290=lndaysgrass) dmv d_period1-d_period4, cl(county)
	*Col 1-3: Sample 1600-1749
	reg fmage pastoral_1290 dmv d_period1-d_period2, cl(county), if period<1726
	reg fmage pastoral_1290 dmv d_period1-d_period2 d_region*, cl(county), if period<1726
	ivreg2 fmage (pastoral_1290=lndaysgrass) dmv d_period1-d_period2, cl(county) , if period<1726

*Table 5: SpringMarriage --> Age at marriage
	*Panel A: 1600-1837
	reg fmage SM_Kussmaul_county [aweight=parishnkuss], cl(county)
	reg fmage SM_Kussmaul_county d_period1-d_period4 [aweight=parishnkuss], cl(county)
	ivreg2 fmage (SM_Kussmaul_county=pastoral_1290) d_period1-d_period4 [aweight=parishnkuss], cl(county) 
	ivreg2 fmage (SM_Kussmaul_county=lndaysgrass) d_period1-d_period4 [aweight=parishnkuss], cl(county) 
	*Panel B: 1600-1749
	reg fmage SM_Kussmaul_county [aweight=parishnkuss], cl(county), if period<1726
	reg fmage SM_Kussmaul_county d_period1-d_period2 [aweight=parishnkuss], cl(county), if period<1726
	ivreg2 fmage (SM_Kussmaul_county=pastoral_1290) d_period1-d_period2 [aweight=parishnkuss], cl(county) , if period<1726
	ivreg2 fmage (SM_Kussmaul_county=lndaysgrass) d_period1-d_period2 [aweight=parishnkuss], cl(county) , if period<1726	
	

///////////////////// Tables for Online Appendix ////////////////

*Table B.7:: For 1836 pastoral share 
	*Col 1-3: Sample 1600-1837
	reg fmage pastoral_1836 d_period1-d_period4, cl(county)
	reg fmage pastoral_1836 d_period1-d_period4 d_region*, cl(county)
	ivreg2 fmage (pastoral_1836=lndaysgrass) d_period1-d_period4, cl(county) 
	*Col 4-6: Sample only 1600-1749
	reg fmage pastoral_1836 d_period1-d_period2, cl(county), if period<1726	
	reg fmage pastoral_1836 d_period1-d_period2 d_region*, cl(county), if period<1726
	ivreg2 fmage (pastoral_1836=lndaysgrass) d_period1-d_period2, cl(county) , if period<1726
	
	
*Table B.5 -- the big IV Table: 
	*column 2
	ivreg2 fmage (pastoral_1290=lndaysgrass feasibility_general) dmv d_period1-d_period4, cl(county) 
	*column 3
	ivreg2 fmage (pastoral_1290=lndaysgrass feasibility_general) dmv d_period1-d_period2, cl(county), if period<1726
	*column 4
	ivreg2 fmage (SM_Kussmaul_county=lndaysgrass feasibility_general) d_period1-d_period4 [aweight=parishnkuss], cl(county)
	*column 5
	ivreg2 fmage (SM_Kussmaul_county=lndaysgrass feasibility_general) d_period1-d_period2 [aweight=parishnkuss], cl(county), if period<1726


/////////////////// Graphs for Online Appendix //////////////
	
*Figure B.11, left panel
	reg fmage pastoral_1290 dmv d_period1-d_period4, cl(county)
	predict y_hat
	gen partial_fmage1 = fmage - (y_hat-4.035637*pastoral_1290)
	drop y_hat 
	
	twoway (lfitci partial_fmage1 pastoral_1290, clcolor(black) fcolor(gray)) (scatter partial_fmage1 pastoral_1290, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)) ///
	, xtitle(Share of Pastoral Land in 1290) ytitle(, size(medium)) ytitle(Female Age at First Marriage (residual)) xtitle(, size(medium))  scheme(s1color) legend(off)

*Figure B.11, right panel
	reg fmage SM_Kussmaul_county [aweight=parishnkuss], cl(county)
	predict y_hat
	gen partial_SM1 = fmage - (y_hat-4.436253*pastoral_1290)
	drop y_hat 
	
	twoway (lfitci fmage SM_Kussmaul_county [aweight=parishnkuss], clcolor(black) fcolor(gray)) (scatter fmage SM_Kussmaul_county [aweight=parishnkuss], mcolor(black) msymbol(circle)  msize(vsmall) mfcolor(dknavy) mlcolor(black)) ///
	, xtitle(County-Level Share of Parishes with Spring Marriage Pattern) ytitle(, size(medium)) ytitle(Female Age at First Marriage) xtitle(, size(medium))  scheme(s1color) legend(off)


*Figure B.12	
	collapse dmv fmage pastoral_1290, by(parish)
		
	sum dmv

	gen dmv_above_mean = 1 if dmv>.073
	recode dmv_above_mean .=0 if dmv~=.

	kdensity fmage if dmv_above_mean==1, bwidth(0.7) generate(femage1_points femage1_dens_values) recast(connected)
	kdensity fmage if dmv_above_mean==0, bwidth(0.7) generate(femage0_points femage0_dens_values) recast(connected)

	label var femage1_dens_values "DMV above mean"
	label var femage0_dens_values "DMV below mean"
	label var fmage "Female age at first marriage"

	twoway (connected femage1_dens_values femage1_points, mcolor(black) msymbol(triangle_hollow) lcolor(black)) ///
	 (connected femage0_dens_values femage0_points, mcolor(green) msymbol(circle_hollow) lcolor(green) lpattern(longdash)), ///
	 legend(cols(1) nobox region(lcolor(white)) position(11) ring(0)) xtitle(Female age at marriage) xtitle(, size(medlarge)) ytitle(, size(medlarge)) scheme(s1color)

	 
	
	
	
	
	
	
	
