clear all

global folder "C:\Users\Nico Voigtlnder\Dropbox\EMP\AER Submission\AER Final Package"
cd "$folder"

use EMP_Dataset_Polltax_Settlement_Sample.dta


quietly{
bysort  county: egen County_samplesize = sum(total)
bysort  county: egen County_WomUnmarried = sum(unmarriedf)
bysort  county: egen County_WomMarried = sum(marriedf)
bysort  county: egen County_MenUnmarried = sum(unmarriedm)
bysort  county: egen County_MenMarried = sum(marriedm)

collapse (mean) County_samplesize-County_MenMarried, by(county)

joinby county using EMP_Dataset_County_Level.dta

gen pastoral_1290 = (100-percarable1290)/100

*Proportion of women in the sample
gen frac_MenUnmarried = County_MenUnmarried/County_samplesize

*The prevelance of unreported unmarried women:
	*a) Fraction of unmarried women in the population
	gen frac_WomUnmarried = County_WomUnmarried/County_samplesize
	*b) The Oman proxy:
	gen lnOman_proxy=ln(County_MenUnmarried/County_WomUnmarried)
	
*The drop in the number of tax payers between 1377 and 1381:
gen drop_taxpayers77_81 = (taxpayers1377-taxpayers1381)/ taxpayers1377


tab region, gen(d_region)


gen ln_popdensity = ln(poppermilesq1290)
}


///////////////////// Table and Figures for the Online Appendix ////////////////	

*Table B.6:
	reg drop_taxpayers77_81 lnOman_proxy [aweight=County_samplesize],r
	reg drop_taxpayers77_81 lnOman_proxy ln_popdensity [aweight=County_samplesize],r 
	reg drop_taxpayers77_81 lnOman_proxy ln_popdensity d_region* [aweight=County_samplesize],r
	reg drop_taxpayers77_81 frac_WomUnmarried [aweight=County_samplesize],r
	reg drop_taxpayers77_81 frac_WomUnmarried ln_popdensity [aweight=County_samplesize],r
	reg drop_taxpayers77_81 frac_WomUnmarried ln_popdensity d_region* [aweight=County_samplesize],r
	reg drop_taxpayers77_81 frac_MenUnmarried [aweight=County_samplesize],r
	reg drop_taxpayers77_81 frac_MenUnmarried ln_popdensity [aweight=County_samplesize],r
	reg drop_taxpayers77_81 frac_MenUnmarried ln_popdensity d_region* [aweight=County_samplesize],r
		


************* Figure B.8: Partial Scatterplot *************	
reg drop_taxpayers77_81 lnOman_proxy ln_popdensity,r
predict y_hat
gen partial_y4 = drop_taxpayers77_81 - (y_hat-.1358358*lnOman_proxy)
drop y_hat 

twoway (lfitci partial_y4 lnOman_proxy, clcolor(black) fcolor(gray)) (scatter partial_y4 lnOman_proxy, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black))  ///
, xtitle(ln(Unmarried Men / Unmarried Women)) ytitle(, size(medium)) ytitle(Drop in Poll Tax Payers 1377-81 (residual)) xtitle(, size(medium))  scheme(s1color) legend(off)

	
************* Figure B.9: Partial Scatterplot *************	
reg frac_MenUnmarried pastoral_1290 ln_popdensity, r 
predict y_hat
gen partial_y6 = frac_MenUnmarried - (y_hat-.2436953*pastoral_1290)
drop y_hat 

twoway (lfitci partial_y6 pastoral_1290, clcolor(black) fcolor(gray)) (scatter partial_y6 pastoral_1290, mcolor(black) msymbol(circle)  msize(medlarge) mfcolor(dknavy) mlcolor(black)) ///
, xtitle(Share of Pastoral Land in 1290) ytitle(, size(medium)) ytitle(Share of unmarried men in 1381 (residual)) xtitle(, size(medium))  scheme(s1color) legend(off)





